==> gongqi.designer_2.3.16.jar: src/got/actions/PerspectiveListener.java <==
package got.actions;

import got.Activator;
import info.gongqi.got.util.GOTMessageDialog;

import org.eclipse.swt.widgets.Display;
import org.eclipse.ui.IPartListener;
import org.eclipse.ui.IPerspectiveDescriptor;
import org.eclipse.ui.IPerspectiveListener;
import org.eclipse.ui.IStartup;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.IWorkbenchPart;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.console.IConsoleConstants;
import org.eclipse.ui.keys.IBindingService;

//IPartListener监听器
public class PerspectiveListener implements IPerspectiveListener , IPartListener, IStartup{

	private PerspectiveListener listener ;
	
	@Override
	public void earlyStartup() {
		// 添加监听
		Display.getDefault().asyncExec(new Runnable() {public void run() {
				try {
					//PlatformUI.getWorkbench().showPerspective("org.eclipse.jdt.ui.JavaPerspective", PlatformUI.getWorkbench().getActiveWorkbenchWindow());
					listener = new PerspectiveListener();
					IWorkbenchPage plat = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage();
					plat.addPartListener( listener); 
					PlatformUI.getWorkbench().getActiveWorkbenchWindow().addPerspectiveListener(listener);
					Activator.bear.openConsole();
					String id = plat.getPerspective().getId();
					if(id.equals("got.actions.GOTPerspectives")){
						try {
							plat.showView("got.actions.MainViewGreatBear");
							plat.showView(IConsoleConstants.ID_CONSOLE_VIEW);
							plat.setPartState(plat.getActivePartReference(), IWorkbenchPage.STATE_RESTORED );
						} catch (PartInitException e) {
							e.printStackTrace();
						}
					}
				} catch (Exception e) {
					e.printStackTrace();
				} 
			} 
		});

		
	}

	@Override
	public void partActivated(IWorkbenchPart part) {
//		String id = part.getSite().getPage().getWorkbenchWindow().getActivePage().getPerspective().getId();
//		 System.out.println(id);DefaultClassLoader
//		 setSystemProperty(id);
//		System.out.println(Thread.currentThread().getContextClassLoader().getClass().getName());
	}

	@Override
	public void partBroughtToTop(IWorkbenchPart part) {

	}

	@Override
	public void partClosed(IWorkbenchPart part) {

	}

	@Override
	public void partDeactivated(IWorkbenchPart part) {
		
	}

	@Override
	public void partOpened(IWorkbenchPart part) {
		
	}
	
	@Override
	public void perspectiveActivated(IWorkbenchPage page,
			IPerspectiveDescriptor perspective) {
		if(page == null){
			return;
		}
		String id = page.getPerspective().getId();
//		page.setPartState(page.getActivePartReference(), IWorkbenchPage.STATE_RESTORED );
		if(id.equals("got.actions.GOTPerspectives")){
			try {
				page.showView("got.actions.MainViewGreatBear");
				page.showView(IConsoleConstants.ID_CONSOLE_VIEW);
				page.setPartState(page.getActivePartReference(), IWorkbenchPage.STATE_RESTORED );
				
			} catch (PartInitException e) {
				e.printStackTrace();
			}
			((IBindingService)PlatformUI.getWorkbench().getAdapter(IBindingService.class)).setKeyFilterEnabled(false);
			GOTMessageDialog.showShells();
//			Thread.currentThread().setContextClassLoader(GOTServiceImpl.class.getClassLoader());
			if(System.getProperty("javax.xml.transform.TransformerFactory") == null){
				System.setProperty("javax.xml.transform.TransformerFactory", "net.sf.saxon.TransformerFactoryImpl");
			}
			 if(Activator.bear == null){
				 Activator.bear = new InfoViewGreatBear();
			 }
		}else {
//			Thread.currentThread().setContextClassLoader(DefaultClassLoader.class.getClassLoader());
			((IBindingService)PlatformUI.getWorkbench().getAdapter(IBindingService.class)).setKeyFilterEnabled(true);
			GOTMessageDialog.hideShells();
			if(System.getProperty("javax.xml.transform.TransformerFactory") != null && System.getProperty("javax.xml.transform.TransformerFactory").equals("net.sf.saxon.TransformerFactoryImpl")){
				System.clearProperty("javax.xml.transform.TransformerFactory");
			}
		}
	}

	@Override
	public void perspectiveChanged(IWorkbenchPage page, IPerspectiveDescriptor perspective, String changeId) {
//		if(perspective.getId().equals("got.actions.GOTPerspectives")){
//			Thread.currentThread().setContextClassLoader(GOTServiceImpl.class.getClassLoader());
//			System.setProperty("javax.xml.transform.TransformerFactory", "net.sf.saxon.TransformerFactoryImpl");
//			((IBindingService)PlatformUI.getWorkbench().getAdapter(IBindingService.class)).setKeyFilterEnabled(false);
//		}else {
//			((IBindingService)PlatformUI.getWorkbench().getAdapter(IBindingService.class)).setKeyFilterEnabled(true);
//			if(System.getProperty("javax.xml.transform.TransformerFactory") != null && System.getProperty("javax.xml.transform.TransformerFactory").equals("net.sf.saxon.TransformerFactoryImpl")){
//				System.clearProperty("javax.xml.transform.TransformerFactory"); 
//			}
//			if(System.getProperty("got.menus.show") != null){
//				System.clearProperty("got.menus.show");
//			}
//		}
		
//		IWorkbenchActivitySupport workbenchActivitySupport = PlatformUI.getWorkbench().getActivitySupport();
//		IActivityManager activityManager = workbenchActivitySupport.getActivityManager();
//		Set<String> enabledActivityIds = new HashSet<String>(activityManager.getEnabledActivityIds());
////		enabledActivityIds.add("arm.activity.disabled");
////		workbenchActivitySupport.setEnabledActivityIds(enabledActivityIds); 
//		if(enabledActivityIds.contains("got.activity.disabled")){
//			System.out.println("123");
//		}
	}

	
//	private void setSystemProperty(String id){
//		if(id.equals("got.actions.GOTPerspectives")){
////			Thread.currentThread().setContextClassLoader(GOTServiceImpl.class.getClassLoader());
//		}else {
//
//		}
//	}
}

==> gongqi.designer_3.3.5.jar: src/got/actions/PerspectiveListener.java <==
package got.actions;

import info.gongqi.got.util.GOTMessageDialog;

import org.apache.log4j.Logger;
import org.eclipse.swt.widgets.Display;
import org.eclipse.ui.IPartListener;
import org.eclipse.ui.IPerspectiveDescriptor;
import org.eclipse.ui.IPerspectiveListener;
import org.eclipse.ui.IStartup;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.IWorkbenchPart;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.console.IConsoleConstants;
import org.eclipse.ui.keys.IBindingService;

import gongqi.gdt.designer.plugin.GOTPlugin;

//IPartListener监听器
public class PerspectiveListener implements IPerspectiveListener , IPartListener, IStartup{

	private static Logger log = Logger.getLogger(PerspectiveListener.class);
	
	private PerspectiveListener listener ;
	
	@Override
	public void earlyStartup() {
		log.debug("earlyStartup2");
		// 添加监听
		Display.getDefault().asyncExec(new Runnable() {
			
			public void run() {
				try {
					//PlatformUI.getWorkbench().showPerspective("org.eclipse.jdt.ui.JavaPerspective", PlatformUI.getWorkbench().getActiveWorkbenchWindow());
					listener = new PerspectiveListener();
					IWorkbenchPage plat = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage();
					plat.addPartListener( listener); 
					PlatformUI.getWorkbench().getActiveWorkbenchWindow().addPerspectiveListener(listener);
//					Activator.bear.openConsole();
					String id = plat.getPerspective().getId();
					if(id.equals("got.actions.GOTPerspectives")){
						try {
							plat.showView("got.actions.MainViewGreatBear");
							plat.showView(IConsoleConstants.ID_CONSOLE_VIEW);
							plat.setPartState(plat.getActivePartReference(), IWorkbenchPage.STATE_RESTORED );
						} catch (PartInitException e) {
							e.printStackTrace();
						}
					}
				} catch (Exception e) {
					e.printStackTrace();
				} 
			} 
		});
	}

	@Override
	public void partActivated(IWorkbenchPart part) {
		
	}

	@Override
	public void partBroughtToTop(IWorkbenchPart part) {
		
	}

	@Override
	public void partClosed(IWorkbenchPart part) {

	}

	@Override
	public void partDeactivated(IWorkbenchPart part) {
		
	}

	@Override
	public void partOpened(IWorkbenchPart part) {
		
	}
	
	@Override
	public void perspectiveActivated(IWorkbenchPage page,
			IPerspectiveDescriptor perspective) {
		log.debug("perspectiveActivated");
		if(page == null){
			return;
		}
		String id = page.getPerspective().getId();
//		page.setPartState(page.getActivePartReference(), IWorkbenchPage.STATE_RESTORED );
		if(id.equals("got.actions.GOTPerspectives")){
			try {
				page.showView("got.actions.MainViewGreatBear");
				page.showView(IConsoleConstants.ID_CONSOLE_VIEW);
				page.setPartState(page.getActivePartReference(), IWorkbenchPage.STATE_RESTORED );
				
			} catch (PartInitException e) {
				e.printStackTrace();
			}
			((IBindingService)PlatformUI.getWorkbench().getAdapter(IBindingService.class)).setKeyFilterEnabled(false);
			GOTMessageDialog.showShells();
//			Thread.currentThread().setContextClassLoader(GOTServiceImpl.class.getClassLoader());
			if(System.getProperty("javax.xml.transform.TransformerFactory") == null){
				System.setProperty("javax.xml.transform.TransformerFactory", "net.sf.saxon.TransformerFactoryImpl");
			}
		}else {
//			Thread.currentThread().setContextClassLoader(DefaultClassLoader.class.getClassLoader());
			((IBindingService)PlatformUI.getWorkbench().getAdapter(IBindingService.class)).setKeyFilterEnabled(true);
			GOTMessageDialog.hideShells();
			if(System.getProperty("javax.xml.transform.TransformerFactory") != null && System.getProperty("javax.xml.transform.TransformerFactory").equals("net.sf.saxon.TransformerFactoryImpl")){
				System.clearProperty("javax.xml.transform.TransformerFactory");
			}
		}
	}

	@Override
	public void perspectiveChanged(IWorkbenchPage page, IPerspectiveDescriptor perspective, String changeId) {
		
	}

}
